# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ec2.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_ec2.proto\x12\x13oak9.tython.aws.ec2\x1a\x13shared/shared.proto\"\xf4\x01\n#CapacityReservationTagSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12P\n\x04tags\x18\x03 \x03(\x0b\x32\x42.oak9.tython.aws.ec2.CapacityReservationTagSpecification.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x96\x03\n\x13\x43\x61pacityReservation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07tenancy\x18\x02 \x01(\t\x12\x15\n\rend_date_type\x18\x03 \x01(\t\x12\x16\n\x0einstance_count\x18\x04 \x01(\x05\x12T\n\x12tag_specifications\x18\x05 \x03(\x0b\x32\x38.oak9.tython.aws.ec2.CapacityReservationTagSpecification\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12\x19\n\x11instance_platform\x18\x07 \x01(\t\x12\x15\n\rinstance_type\x18\x08 \x01(\t\x12\x19\n\x11\x65phemeral_storage\x18\t \x01(\x08\x12\x1f\n\x17instance_match_criteria\x18\n \x01(\t\x12\x10\n\x08\x65nd_date\x18\x0b \x01(\t\x12\x15\n\rebs_optimized\x18\x0c \x01(\x08\"\xd2)\n\x03\x45\x43\x32\x12\x46\n\x14\x63\x61pacity_reservation\x18\x01 \x03(\x0b\x32(.oak9.tython.aws.ec2.CapacityReservation\x12V\n\x1d\x63lient_vpn_authorization_rule\x18\x02 \x03(\x0b\x32/.oak9.tython.aws.ec2.ClientVpnAuthorizationRule\x12\x43\n\x13\x63lient_vpn_endpoint\x18\x03 \x03(\x0b\x32&.oak9.tython.aws.ec2.ClientVpnEndpoint\x12=\n\x10\x63lient_vpn_route\x18\x04 \x03(\x0b\x32#.oak9.tython.aws.ec2.ClientVpnRoute\x12\x65\n%client_vpn_target_network_association\x18\x05 \x03(\x0b\x32\x36.oak9.tython.aws.ec2.ClientVpnTargetNetworkAssociation\x12>\n\x10\x63ustomer_gateway\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.ec2.CustomerGateway\x12\x31\n\ne_c2_fleet\x18\x07 \x03(\x0b\x32\x1d.oak9.tython.aws.ec2.EC2Fleet\x12&\n\x04\x65_ip\x18\x08 \x03(\x0b\x32\x18.oak9.tython.aws.ec2.EIP\x12=\n\x10\x65_ip_association\x18\t \x03(\x0b\x32#.oak9.tython.aws.ec2.EIPAssociation\x12T\n\x1c\x65gress_only_internet_gateway\x18\n \x03(\x0b\x32..oak9.tython.aws.ec2.EgressOnlyInternetGateway\x12.\n\x08\x66low_log\x18\x0b \x03(\x0b\x32\x1c.oak9.tython.aws.ec2.FlowLog\x12Z\n\x1fgateway_route_table_association\x18\x0c \x03(\x0b\x32\x31.oak9.tython.aws.ec2.GatewayRouteTableAssociation\x12\'\n\x04host\x18\r \x03(\x0b\x32\x19.oak9.tython.aws.ec2.Host\x12>\n\x10internet_gateway\x18\x0e \x03(\x0b\x32$.oak9.tython.aws.ec2.InternetGateway\x12\x43\n\x13local_gateway_route\x18\x0f \x03(\x0b\x32&.oak9.tython.aws.ec2.LocalGatewayRoute\x12l\n)local_gateway_route_table_vpc_association\x18\x10 \x03(\x0b\x32\x39.oak9.tython.aws.ec2.LocalGatewayRouteTableVPCAssociation\x12\x34\n\x0bnat_gateway\x18\x11 \x03(\x0b\x32\x1f.oak9.tython.aws.ec2.NatGateway\x12@\n\x11network_interface\x18\x12 \x03(\x0b\x32%.oak9.tython.aws.ec2.NetworkInterface\x12U\n\x1cnetwork_interface_attachment\x18\x13 \x03(\x0b\x32/.oak9.tython.aws.ec2.NetworkInterfaceAttachment\x12U\n\x1cnetwork_interface_permission\x18\x14 \x03(\x0b\x32/.oak9.tython.aws.ec2.NetworkInterfacePermission\x12<\n\x0fplacement_group\x18\x15 \x03(\x0b\x32#.oak9.tython.aws.ec2.PlacementGroup\x12\x34\n\x0bprefix_list\x18\x16 \x03(\x0b\x32\x1f.oak9.tython.aws.ec2.PrefixList\x12\x32\n\nspot_fleet\x18\x17 \x03(\x0b\x32\x1e.oak9.tython.aws.ec2.SpotFleet\x12G\n\x15traffic_mirror_filter\x18\x18 \x03(\x0b\x32(.oak9.tython.aws.ec2.TrafficMirrorFilter\x12P\n\x1atraffic_mirror_filter_rule\x18\x19 \x03(\x0b\x32,.oak9.tython.aws.ec2.TrafficMirrorFilterRule\x12I\n\x16traffic_mirror_session\x18\x1a \x03(\x0b\x32).oak9.tython.aws.ec2.TrafficMirrorSession\x12G\n\x15traffic_mirror_target\x18\x1b \x03(\x0b\x32(.oak9.tython.aws.ec2.TrafficMirrorTarget\x12<\n\x0ftransit_gateway\x18\x1c \x03(\x0b\x32#.oak9.tython.aws.ec2.TransitGateway\x12Q\n\x1atransit_gateway_attachment\x18\x1d \x03(\x0b\x32-.oak9.tython.aws.ec2.TransitGatewayAttachment\x12G\n\x15transit_gateway_route\x18\x1e \x03(\x0b\x32(.oak9.tython.aws.ec2.TransitGatewayRoute\x12R\n\x1btransit_gateway_route_table\x18\x1f \x03(\x0b\x32-.oak9.tython.aws.ec2.TransitGatewayRouteTable\x12i\n\'transit_gateway_route_table_association\x18  \x03(\x0b\x32\x38.oak9.tython.aws.ec2.TransitGatewayRouteTableAssociation\x12i\n\'transit_gateway_route_table_propagation\x18! \x03(\x0b\x32\x38.oak9.tython.aws.ec2.TransitGatewayRouteTablePropagation\x12I\n\x16vpc_gateway_attachment\x18\" \x03(\x0b\x32).oak9.tython.aws.ec2.VPCGatewayAttachment\x12:\n\x0evpn_connection\x18# \x03(\x0b\x32\".oak9.tython.aws.ec2.VPNConnection\x12\x45\n\x14vpn_connection_route\x18$ \x03(\x0b\x32\'.oak9.tython.aws.ec2.VPNConnectionRoute\x12\x34\n\x0bvpn_gateway\x18% \x03(\x0b\x32\x1f.oak9.tython.aws.ec2.VPNGateway\x12V\n\x1dvpn_gateway_route_propagation\x18& \x03(\x0b\x32/.oak9.tython.aws.ec2.VPNGatewayRoutePropagation\x12+\n\x06volume\x18\' \x03(\x0b\x32\x1b.oak9.tython.aws.ec2.Volume\x12@\n\x11volume_attachment\x18( \x03(\x0b\x32%.oak9.tython.aws.ec2.VolumeAttachment\x12Y\n\x1einstance_association_parameter\x18) \x03(\x0b\x32\x31.oak9.tython.aws.ec2.InstanceAssociationParameter\x12V\n\x1dinstance_block_device_mapping\x18* \x03(\x0b\x32/.oak9.tython.aws.ec2.InstanceBlockDeviceMapping\x12\x45\n\x14instance_cpu_options\x18+ \x03(\x0b\x32\'.oak9.tython.aws.ec2.InstanceCpuOptions\x12W\n\x1dinstance_credit_specification\x18, \x03(\x0b\x32\x30.oak9.tython.aws.ec2.InstanceCreditSpecification\x12`\n\"instance_elastic_gpu_specification\x18- \x03(\x0b\x32\x34.oak9.tython.aws.ec2.InstanceElasticGpuSpecification\x12h\n&instance_elastic_inference_accelerator\x18. \x03(\x0b\x32\x38.oak9.tython.aws.ec2.InstanceElasticInferenceAccelerator\x12U\n\x1cinstance_hibernation_options\x18/ \x03(\x0b\x32/.oak9.tython.aws.ec2.InstanceHibernationOptions\x12X\n\x1einstance_instance_ipv6_address\x18\x30 \x03(\x0b\x32\x30.oak9.tython.aws.ec2.InstanceInstanceIpv6Address\x12h\n&instance_launch_template_specification\x18\x31 \x03(\x0b\x32\x38.oak9.tython.aws.ec2.InstanceLaunchTemplateSpecification\x12Y\n\x1einstance_license_specification\x18\x32 \x03(\x0b\x32\x31.oak9.tython.aws.ec2.InstanceLicenseSpecification\x12Q\n\x1ainstance_network_interface\x18\x33 \x03(\x0b\x32-.oak9.tython.aws.ec2.InstanceNetworkInterface\x12M\n\x18instance_ssm_association\x18\x34 \x03(\x0b\x32+.oak9.tython.aws.ec2.InstanceSsmAssociation\x12<\n\x0finstance_volume\x18\x35 \x03(\x0b\x32#.oak9.tython.aws.ec2.InstanceVolume\x12\x63\n$launch_template_block_device_mapping\x18\x36 \x03(\x0b\x32\x35.oak9.tython.aws.ec2.LaunchTemplateBlockDeviceMapping\x12\x7f\n2launch_template_capacity_reservation_specification\x18\x37 \x03(\x0b\x32\x43.oak9.tython.aws.ec2.LaunchTemplateCapacityReservationSpecification\x12R\n\x1blaunch_template_cpu_options\x18\x38 \x03(\x0b\x32-.oak9.tython.aws.ec2.LaunchTemplateCpuOptions\x12\x64\n$launch_template_credit_specification\x18\x39 \x03(\x0b\x32\x36.oak9.tython.aws.ec2.LaunchTemplateCreditSpecification\x12m\n)launch_template_elastic_gpu_specification\x18: \x03(\x0b\x32:.oak9.tython.aws.ec2.LaunchTemplateElasticGpuSpecification\x12\x62\n#launch_template_hibernation_options\x18; \x03(\x0b\x32\x35.oak9.tython.aws.ec2.LaunchTemplateHibernationOptions\x12\x63\n$launch_template_iam_instance_profile\x18< \x03(\x0b\x32\x35.oak9.tython.aws.ec2.LaunchTemplateIamInstanceProfile\x12i\n\'launch_template_instance_market_options\x18= \x03(\x0b\x32\x38.oak9.tython.aws.ec2.LaunchTemplateInstanceMarketOptions\x12L\n\x18launch_template_ipv6_add\x18> \x03(\x0b\x32*.oak9.tython.aws.ec2.LaunchTemplateIpv6Add\x12\x63\n$launch_template_launch_template_data\x18? \x03(\x0b\x32\x35.oak9.tython.aws.ec2.LaunchTemplateLaunchTemplateData\x12H\n\x16network_acl_entry_icmp\x18@ \x03(\x0b\x32(.oak9.tython.aws.ec2.NetworkAclEntryIcmp\x12S\n\x1cnetwork_acl_entry_port_range\x18\x41 \x03(\x0b\x32-.oak9.tython.aws.ec2.NetworkAclEntryPortRange\x12G\n\x15security_group_egress\x18\x42 \x03(\x0b\x32(.oak9.tython.aws.ec2.SecurityGroupEgress\x12I\n\x16security_group_ingress\x18\x43 \x03(\x0b\x32).oak9.tython.aws.ec2.SecurityGroupIngress\"\xde\x01\n\x1a\x43lientVpnAuthorizationRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x63lient_vpn_endpoint_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65ss_group_id\x18\x04 \x01(\t\x12\x1b\n\x13target_network_cidr\x18\x05 \x01(\t\x12\x1c\n\x14\x61uthorize_all_groups\x18\x06 \x01(\x08\"\xae\x01\n%ClientVpnEndpointConnectionLogOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63loudwatch_log_stream\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\x12\x1c\n\x14\x63loudwatch_log_group\x18\x04 \x01(\t\"\xf0\x01\n!ClientVpnEndpointTagSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12N\n\x04tags\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.ec2.ClientVpnEndpointTagSpecification.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x97\x01\n1ClientVpnEndpointCertificateAuthenticationRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12)\n!client_root_certificate_chain_arn\x18\x02 \x01(\t\"\x85\x01\n/ClientVpnEndpointFederatedAuthenticationRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11saml_provider_arn\x18\x02 \x01(\t\"\x87\x01\n6ClientVpnEndpointDirectoryServiceAuthenticationRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0c\x64irectory_id\x18\x02 \x01(\t\"\x9d\x03\n,ClientVpnEndpointClientAuthenticationRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x65\n\x15mutual_authentication\x18\x02 \x01(\x0b\x32\x46.oak9.tython.aws.ec2.ClientVpnEndpointCertificateAuthenticationRequest\x12\x66\n\x18\x66\x65\x64\x65rated_authentication\x18\x03 \x01(\x0b\x32\x44.oak9.tython.aws.ec2.ClientVpnEndpointFederatedAuthenticationRequest\x12\x65\n\x10\x61\x63tive_directory\x18\x04 \x01(\x0b\x32K.oak9.tython.aws.ec2.ClientVpnEndpointDirectoryServiceAuthenticationRequest\"\xb4\x04\n\x11\x43lientVpnEndpoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63lient_cidr_block\x18\x02 \x01(\t\x12Z\n\x16\x63onnection_log_options\x18\x03 \x01(\x0b\x32:.oak9.tython.aws.ec2.ClientVpnEndpointConnectionLogOptions\x12\x14\n\x0csplit_tunnel\x18\x04 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12R\n\x12tag_specifications\x18\x06 \x03(\x0b\x32\x36.oak9.tython.aws.ec2.ClientVpnEndpointTagSpecification\x12\x0e\n\x06vpc_id\x18\x07 \x01(\t\x12\x61\n\x16\x61uthentication_options\x18\x08 \x03(\x0b\x32\x41.oak9.tython.aws.ec2.ClientVpnEndpointClientAuthenticationRequest\x12\x1e\n\x16server_certificate_arn\x18\t \x01(\t\x12\x13\n\x0b\x64ns_servers\x18\n \x03(\t\x12\x1a\n\x12transport_protocol\x18\x0b \x01(\t\x12\x1a\n\x12security_group_ids\x18\x0c \x03(\t\x12\x10\n\x08vpn_port\x18\r \x01(\x05\"\xbc\x01\n\x0e\x43lientVpnRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x63lient_vpn_endpoint_id\x18\x02 \x01(\t\x12\x1c\n\x14target_vpc_subnet_id\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x1e\n\x16\x64\x65stination_cidr_block\x18\x05 \x01(\t\"\x8f\x01\n!ClientVpnTargetNetworkAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x63lient_vpn_endpoint_id\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\"\xe8\x01\n\x0f\x43ustomerGateway\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x62gp_asn\x18\x02 \x01(\x05\x12\x12\n\nip_address\x18\x03 \x01(\t\x12<\n\x04tags\x18\x04 \x03(\x0b\x32..oak9.tython.aws.ec2.CustomerGateway.TagsEntry\x12\x0c\n\x04type\x18\x05 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xeb\x01\n*EC2FleetTargetCapacitySpecificationRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12$\n\x1c\x64\x65\x66\x61ult_target_capacity_type\x18\x02 \x01(\t\x12\x1d\n\x15total_target_capacity\x18\x03 \x01(\x05\x12!\n\x19on_demand_target_capacity\x18\x04 \x01(\x05\x12\x1c\n\x14spot_target_capacity\x18\x05 \x01(\x05\"|\n)EC2FleetCapacityReservationOptionsRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eusage_strategy\x18\x02 \x01(\t\"\xd2\x02\n\x1e\x45\x43\x32\x46leetOnDemandOptionsRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18single_availability_zone\x18\x02 \x01(\x08\x12\x1b\n\x13\x61llocation_strategy\x18\x03 \x01(\t\x12\x1c\n\x14single_instance_type\x18\x04 \x01(\x08\x12\x1b\n\x13min_target_capacity\x18\x05 \x01(\x05\x12\x17\n\x0fmax_total_price\x18\x06 \x01(\t\x12\x64\n\x1c\x63\x61pacity_reservation_options\x18\x07 \x01(\x0b\x32>.oak9.tython.aws.ec2.EC2FleetCapacityReservationOptionsRequest\"\xde\x01\n\x18\x45\x43\x32\x46leetTagSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12\x45\n\x04tags\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.ec2.EC2FleetTagSpecification.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb5\x02\n\x1a\x45\x43\x32\x46leetSpotOptionsRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18single_availability_zone\x18\x02 \x01(\x08\x12\x1b\n\x13\x61llocation_strategy\x18\x03 \x01(\t\x12\x1c\n\x14single_instance_type\x18\x04 \x01(\x08\x12\x1b\n\x13min_target_capacity\x18\x05 \x01(\x05\x12\x17\n\x0fmax_total_price\x18\x06 \x01(\t\x12&\n\x1einstance_interruption_behavior\x18\x07 \x01(\t\x12#\n\x1binstance_pools_to_use_count\x18\x08 \x01(\x05\"\xb5\x01\n/EC2FleetFleetLaunchTemplateSpecificationRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1c\n\x14launch_template_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x1a\n\x12launch_template_id\x18\x04 \x01(\t\"\x81\x02\n\x11\x45\x43\x32\x46leetPlacement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x0f\n\x07tenancy\x18\x03 \x01(\t\x12\x15\n\rspread_domain\x18\x04 \x01(\t\x12\x18\n\x10partition_number\x18\x05 \x01(\x05\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12\x10\n\x08\x61\x66\x66inity\x18\x07 \x01(\t\x12\x0f\n\x07host_id\x18\x08 \x01(\t\x12\x1f\n\x17host_resource_group_arn\x18\t \x01(\t\"\xa6\x02\n+EC2FleetFleetLaunchTemplateOverridesRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11weighted_capacity\x18\x02 \x01(\x01\x12\x39\n\tplacement\x18\x03 \x01(\x0b\x32&.oak9.tython.aws.ec2.EC2FleetPlacement\x12\x10\n\x08priority\x18\x04 \x01(\x01\x12\x19\n\x11\x61vailability_zone\x18\x05 \x01(\t\x12\x11\n\tsubnet_id\x18\x06 \x01(\t\x12\x15\n\rinstance_type\x18\x07 \x01(\t\x12\x11\n\tmax_price\x18\x08 \x01(\t\"\xa5\x02\n(EC2FleetFleetLaunchTemplateConfigRequest\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12k\n\x1dlaunch_template_specification\x18\x02 \x01(\x0b\x32\x44.oak9.tython.aws.ec2.EC2FleetFleetLaunchTemplateSpecificationRequest\x12S\n\toverrides\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.ec2.EC2FleetFleetLaunchTemplateOverridesRequest\"\xa2\x05\n\x08\x45\x43\x32\x46leet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x66\n\x1dtarget_capacity_specification\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.ec2.EC2FleetTargetCapacitySpecificationRequest\x12N\n\x11on_demand_options\x18\x03 \x01(\x0b\x32\x33.oak9.tython.aws.ec2.EC2FleetOnDemandOptionsRequest\x12\x0c\n\x04type\x18\x04 \x01(\t\x12*\n\"excess_capacity_termination_policy\x18\x05 \x01(\t\x12I\n\x12tag_specifications\x18\x06 \x03(\x0b\x32-.oak9.tython.aws.ec2.EC2FleetTagSpecification\x12\x45\n\x0cspot_options\x18\x07 \x01(\x0b\x32/.oak9.tython.aws.ec2.EC2FleetSpotOptionsRequest\x12\x12\n\nvalid_from\x18\x08 \x01(\t\x12#\n\x1breplace_unhealthy_instances\x18\t \x01(\x08\x12^\n\x17launch_template_configs\x18\n \x03(\x0b\x32=.oak9.tython.aws.ec2.EC2FleetFleetLaunchTemplateConfigRequest\x12+\n#terminate_instances_with_expiration\x18\x0b \x01(\x08\x12\x13\n\x0bvalid_until\x18\x0c \x01(\t\"\xdc\x01\n\x03\x45IP\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x64omain\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x18\n\x10public_ipv4_pool\x18\x04 \x01(\t\x12\x30\n\x04tags\x18\x05 \x03(\x0b\x32\".oak9.tython.aws.ec2.EIP.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x01\n\x0e\x45IPAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rallocation_id\x18\x02 \x01(\t\x12\x0c\n\x04\x65_ip\x18\x03 \x01(\t\x12\x13\n\x0binstance_id\x18\x04 \x01(\t\x12\x1c\n\x14network_interface_id\x18\x05 \x01(\t\x12\x1a\n\x12private_ip_address\x18\x06 \x01(\t\"d\n\x19\x45gressOnlyInternetGateway\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06vpc_id\x18\x02 \x01(\t\"\x91\x03\n\x07\x46lowLog\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x64\x65liver_logs_permission_arn\x18\x02 \x01(\t\x12\x17\n\x0flog_destination\x18\x03 \x01(\t\x12\x1c\n\x14log_destination_type\x18\x04 \x01(\t\x12\x12\n\nlog_format\x18\x05 \x01(\t\x12\x16\n\x0elog_group_name\x18\x06 \x01(\t\x12 \n\x18max_aggregation_interval\x18\x07 \x01(\x05\x12\x13\n\x0bresource_id\x18\x08 \x01(\t\x12\x15\n\rresource_type\x18\t \x01(\t\x12\x34\n\x04tags\x18\n \x03(\x0b\x32&.oak9.tython.aws.ec2.FlowLog.TagsEntry\x12\x14\n\x0ctraffic_type\x18\x0b \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x1cGatewayRouteTableAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0eroute_table_id\x18\x02 \x01(\t\x12\x12\n\ngateway_id\x18\x03 \x01(\t\"\xa0\x01\n\x04Host\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61uto_placement\x18\x02 \x01(\t\x12\x19\n\x11\x61vailability_zone\x18\x03 \x01(\t\x12\x15\n\rhost_recovery\x18\x04 \x01(\t\x12\x15\n\rinstance_type\x18\x05 \x01(\t\"\xb5\x01\n\x0fInternetGateway\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12<\n\x04tags\x18\x02 \x03(\x0b\x32..oak9.tython.aws.ec2.InternetGateway.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xc4\x01\n\x11LocalGatewayRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65stination_cidr_block\x18\x02 \x01(\t\x12$\n\x1clocal_gateway_route_table_id\x18\x03 \x01(\t\x12\x30\n(local_gateway_virtual_interface_group_id\x18\x04 \x01(\t\"\xe7\x01\n(LocalGatewayRouteTableVPCAssociationTags\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12U\n\x04tags\x18\x02 \x03(\x0b\x32G.oak9.tython.aws.ec2.LocalGatewayRouteTableVPCAssociationTags.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe2\x01\n$LocalGatewayRouteTableVPCAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12$\n\x1clocal_gateway_route_table_id\x18\x02 \x01(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x12K\n\x04tags\x18\x04 \x01(\x0b\x32=.oak9.tython.aws.ec2.LocalGatewayRouteTableVPCAssociationTags\"\xd5\x01\n\nNatGateway\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rallocation_id\x18\x02 \x01(\t\x12\x11\n\tsubnet_id\x18\x03 \x01(\t\x12\x37\n\x04tags\x18\x04 \x03(\x0b\x32).oak9.tython.aws.ec2.NatGateway.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"t\n#NetworkInterfaceInstanceIpv6Address\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\"\x95\x01\n-NetworkInterfacePrivateIpAddressSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07primary\x18\x02 \x01(\x08\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\"\xbd\x04\n\x10NetworkInterface\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x11\n\tgroup_set\x18\x03 \x03(\t\x12\x16\n\x0einterface_type\x18\x04 \x01(\t\x12\x1a\n\x12ipv6_address_count\x18\x05 \x01(\x05\x12P\n\x0eipv6_addresses\x18\x06 \x03(\x0b\x32\x38.oak9.tython.aws.ec2.NetworkInterfaceInstanceIpv6Address\x12\x1a\n\x12private_ip_address\x18\x07 \x01(\t\x12`\n\x14private_ip_addresses\x18\x08 \x03(\x0b\x32\x42.oak9.tython.aws.ec2.NetworkInterfacePrivateIpAddressSpecification\x12*\n\"secondary_private_ip_address_count\x18\t \x01(\x05\x12\x19\n\x11source_dest_check\x18\n \x01(\x08\x12\x11\n\tsubnet_id\x18\x0b \x01(\t\x12=\n\x04tags\x18\x0c \x03(\x0b\x32/.oak9.tython.aws.ec2.NetworkInterface.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x01\n\x1aNetworkInterfaceAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x02 \x01(\x08\x12\x14\n\x0c\x64\x65vice_index\x18\x03 \x01(\t\x12\x13\n\x0binstance_id\x18\x04 \x01(\t\x12\x1c\n\x14network_interface_id\x18\x05 \x01(\t\"\x9f\x01\n\x1aNetworkInterfacePermission\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ws_account_id\x18\x02 \x01(\t\x12\x1c\n\x14network_interface_id\x18\x03 \x01(\t\x12\x12\n\npermission\x18\x04 \x01(\t\"[\n\x0ePlacementGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08strategy\x18\x02 \x01(\t\"m\n\x0fPrefixListEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x63idr\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\xa9\x02\n\nPrefixList\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10prefix_list_name\x18\x02 \x01(\t\x12\x16\n\x0e\x61\x64\x64ress_family\x18\x03 \x01(\t\x12\x13\n\x0bmax_entries\x18\x04 \x01(\x05\x12\x37\n\x04tags\x18\x05 \x03(\x0b\x32).oak9.tython.aws.ec2.PrefixList.TagsEntry\x12\x35\n\x07\x65ntries\x18\x06 \x03(\x0b\x32$.oak9.tython.aws.ec2.PrefixListEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd1\x01\n\x17SpotFleetEbsBlockDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x02 \x01(\x08\x12\x11\n\tencrypted\x18\x03 \x01(\x08\x12\x0c\n\x04iops\x18\x04 \x01(\x05\x12\x13\n\x0bsnapshot_id\x18\x05 \x01(\t\x12\x13\n\x0bvolume_size\x18\x06 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x07 \x01(\t\"\xcf\x01\n\x1bSpotFleetBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x39\n\x03\x65\x62s\x18\x03 \x01(\x0b\x32,.oak9.tython.aws.ec2.SpotFleetEbsBlockDevice\x12\x11\n\tno_device\x18\x04 \x01(\t\x12\x14\n\x0cvirtual_name\x18\x05 \x01(\t\"p\n(SpotFleetIamInstanceProfileSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\"h\n\x1cSpotFleetSpotFleetMonitoring\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"m\n\x1cSpotFleetInstanceIpv6Address\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\"\x8e\x01\n&SpotFleetPrivateIpAddressSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07primary\x18\x02 \x01(\x08\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\"\x87\x04\n.SpotFleetInstanceNetworkInterfaceSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x61ssociate_public_ip_address\x18\x02 \x01(\x08\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65vice_index\x18\x05 \x01(\x05\x12\x0e\n\x06groups\x18\x06 \x03(\t\x12\x1a\n\x12ipv6_address_count\x18\x07 \x01(\x05\x12I\n\x0eipv6_addresses\x18\x08 \x03(\x0b\x32\x31.oak9.tython.aws.ec2.SpotFleetInstanceIpv6Address\x12\x1c\n\x14network_interface_id\x18\t \x01(\t\x12Y\n\x14private_ip_addresses\x18\n \x03(\x0b\x32;.oak9.tython.aws.ec2.SpotFleetPrivateIpAddressSpecification\x12*\n\"secondary_private_ip_address_count\x18\x0b \x01(\x05\x12\x11\n\tsubnet_id\x18\x0c \x01(\t\"\x91\x01\n\x16SpotFleetSpotPlacement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\x12\n\ngroup_name\x18\x03 \x01(\t\x12\x0f\n\x07tenancy\x18\x04 \x01(\t\"e\n\x18SpotFleetGroupIdentifier\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08group_id\x18\x02 \x01(\t\"\xf2\x01\n\"SpotFleetSpotFleetTagSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12O\n\x04tags\x18\x03 \x03(\x0b\x32\x41.oak9.tython.aws.ec2.SpotFleetSpotFleetTagSpecification.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xe1\x06\n%SpotFleetSpotFleetLaunchSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12O\n\x15\x62lock_device_mappings\x18\x02 \x03(\x0b\x32\x30.oak9.tython.aws.ec2.SpotFleetBlockDeviceMapping\x12\x15\n\rebs_optimized\x18\x03 \x01(\x08\x12[\n\x14iam_instance_profile\x18\x04 \x01(\x0b\x32=.oak9.tython.aws.ec2.SpotFleetIamInstanceProfileSpecification\x12\x10\n\x08image_id\x18\x05 \x01(\t\x12\x15\n\rinstance_type\x18\x06 \x01(\t\x12\x11\n\tkernel_id\x18\x07 \x01(\t\x12\x10\n\x08key_name\x18\x08 \x01(\t\x12\x45\n\nmonitoring\x18\t \x01(\x0b\x32\x31.oak9.tython.aws.ec2.SpotFleetSpotFleetMonitoring\x12_\n\x12network_interfaces\x18\n \x03(\x0b\x32\x43.oak9.tython.aws.ec2.SpotFleetInstanceNetworkInterfaceSpecification\x12>\n\tplacement\x18\x0b \x01(\x0b\x32+.oak9.tython.aws.ec2.SpotFleetSpotPlacement\x12\x12\n\nramdisk_id\x18\x0c \x01(\t\x12\x46\n\x0fsecurity_groups\x18\r \x03(\x0b\x32-.oak9.tython.aws.ec2.SpotFleetGroupIdentifier\x12\x12\n\nspot_price\x18\x0e \x01(\t\x12\x11\n\tsubnet_id\x18\x0f \x01(\t\x12S\n\x12tag_specifications\x18\x10 \x03(\x0b\x32\x37.oak9.tython.aws.ec2.SpotFleetSpotFleetTagSpecification\x12\x11\n\tuser_data\x18\x11 \x01(\t\x12\x19\n\x11weighted_capacity\x18\x12 \x01(\x01\"\xaf\x01\n)SpotFleetFleetLaunchTemplateSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12launch_template_id\x18\x02 \x01(\t\x12\x1c\n\x14launch_template_name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"\xcf\x01\n SpotFleetLaunchTemplateOverrides\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x61vailability_zone\x18\x02 \x01(\t\x12\x15\n\rinstance_type\x18\x03 \x01(\t\x12\x12\n\nspot_price\x18\x04 \x01(\t\x12\x11\n\tsubnet_id\x18\x05 \x01(\t\x12\x19\n\x11weighted_capacity\x18\x06 \x01(\x01\"\x89\x02\n\x1dSpotFleetLaunchTemplateConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x65\n\x1dlaunch_template_specification\x18\x02 \x01(\x0b\x32>.oak9.tython.aws.ec2.SpotFleetFleetLaunchTemplateSpecification\x12H\n\toverrides\x18\x03 \x03(\x0b\x32\x35.oak9.tython.aws.ec2.SpotFleetLaunchTemplateOverrides\"e\n\x1cSpotFleetClassicLoadBalancer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\"\xb1\x01\n#SpotFleetClassicLoadBalancersConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\x16\x63lassic_load_balancers\x18\x02 \x03(\x0b\x32\x31.oak9.tython.aws.ec2.SpotFleetClassicLoadBalancer\"\\\n\x14SpotFleetTargetGroup\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\"\x98\x01\n\x1bSpotFleetTargetGroupsConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12@\n\rtarget_groups\x18\x02 \x03(\x0b\x32).oak9.tython.aws.ec2.SpotFleetTargetGroup\"\x88\x02\n\x1cSpotFleetLoadBalancersConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12_\n\x1d\x63lassic_load_balancers_config\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.ec2.SpotFleetClassicLoadBalancersConfig\x12N\n\x14target_groups_config\x18\x03 \x01(\x0b\x32\x30.oak9.tython.aws.ec2.SpotFleetTargetGroupsConfig\"\x91\x05\n#SpotFleetSpotFleetRequestConfigData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x61llocation_strategy\x18\x02 \x01(\t\x12*\n\"excess_capacity_termination_policy\x18\x03 \x01(\t\x12\x16\n\x0eiam_fleet_role\x18\x04 \x01(\t\x12&\n\x1einstance_interruption_behavior\x18\x05 \x01(\t\x12Y\n\x15launch_specifications\x18\x06 \x03(\x0b\x32:.oak9.tython.aws.ec2.SpotFleetSpotFleetLaunchSpecification\x12S\n\x17launch_template_configs\x18\x07 \x03(\x0b\x32\x32.oak9.tython.aws.ec2.SpotFleetLaunchTemplateConfig\x12P\n\x15load_balancers_config\x18\x08 \x01(\x0b\x32\x31.oak9.tython.aws.ec2.SpotFleetLoadBalancersConfig\x12#\n\x1breplace_unhealthy_instances\x18\t \x01(\x08\x12\x12\n\nspot_price\x18\n \x01(\t\x12\x17\n\x0ftarget_capacity\x18\x0b \x01(\x05\x12+\n#terminate_instances_with_expiration\x18\x0c \x01(\x08\x12\x12\n\nvalid_from\x18\r \x01(\t\x12\x13\n\x0bvalid_until\x18\x0e \x01(\t\"\xa6\x01\n\tSpotFleet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12`\n\x1espot_fleet_request_config_data\x18\x02 \x01(\x0b\x32\x38.oak9.tython.aws.ec2.SpotFleetSpotFleetRequestConfigData\"\xec\x01\n\x13TrafficMirrorFilter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x18\n\x10network_services\x18\x03 \x03(\t\x12@\n\x04tags\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.ec2.TrafficMirrorFilter.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x8c\x01\n-TrafficMirrorFilterRuleTrafficMirrorPortRange\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tfrom_port\x18\x02 \x01(\x05\x12\x0f\n\x07to_port\x18\x03 \x01(\x05\"\xde\x03\n\x17TrafficMirrorFilterRule\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x16\x64\x65stination_port_range\x18\x02 \x01(\x0b\x32\x42.oak9.tython.aws.ec2.TrafficMirrorFilterRuleTrafficMirrorPortRange\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12]\n\x11source_port_range\x18\x04 \x01(\x0b\x32\x42.oak9.tython.aws.ec2.TrafficMirrorFilterRuleTrafficMirrorPortRange\x12\x13\n\x0brule_action\x18\x05 \x01(\t\x12\x19\n\x11source_cidr_block\x18\x06 \x01(\t\x12\x13\n\x0brule_number\x18\x07 \x01(\x05\x12\x1e\n\x16\x64\x65stination_cidr_block\x18\x08 \x01(\t\x12 \n\x18traffic_mirror_filter_id\x18\t \x01(\t\x12\x19\n\x11traffic_direction\x18\n \x01(\t\x12\x10\n\x08protocol\x18\x0b \x01(\x05\"\x81\x03\n\x14TrafficMirrorSession\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12 \n\x18traffic_mirror_target_id\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0esession_number\x18\x04 \x01(\x05\x12\x1a\n\x12virtual_network_id\x18\x05 \x01(\x05\x12\x15\n\rpacket_length\x18\x06 \x01(\x05\x12\x1c\n\x14network_interface_id\x18\x07 \x01(\t\x12 \n\x18traffic_mirror_filter_id\x18\x08 \x01(\t\x12\x41\n\x04tags\x18\t \x03(\x0b\x32\x33.oak9.tython.aws.ec2.TrafficMirrorSession.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x93\x02\n\x13TrafficMirrorTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19network_load_balancer_arn\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x1c\n\x14network_interface_id\x18\x04 \x01(\t\x12@\n\x04tags\x18\x05 \x03(\x0b\x32\x32.oak9.tython.aws.ec2.TrafficMirrorTarget.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa5\x03\n\x0eTransitGateway\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1f\x64\x65\x66\x61ult_route_table_propagation\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12&\n\x1e\x61uto_accept_shared_attachments\x18\x04 \x01(\t\x12\'\n\x1f\x64\x65\x66\x61ult_route_table_association\x18\x05 \x01(\t\x12\x18\n\x10vpn_ecmp_support\x18\x06 \x01(\t\x12\x13\n\x0b\x64ns_support\x18\x07 \x01(\t\x12\x19\n\x11multicast_support\x18\x08 \x01(\t\x12\x17\n\x0f\x61mazon_side_asn\x18\t \x01(\x05\x12;\n\x04tags\x18\n \x03(\x0b\x32-.oak9.tython.aws.ec2.TransitGateway.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x02\n\x18TransitGatewayAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12transit_gateway_id\x18\x02 \x01(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x12\x12\n\nsubnet_ids\x18\x04 \x03(\t\x12\x45\n\x04tags\x18\x05 \x03(\x0b\x32\x37.oak9.tython.aws.ec2.TransitGatewayAttachment.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd0\x01\n\x13TransitGatewayRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1etransit_gateway_route_table_id\x18\x02 \x01(\t\x12\x1e\n\x16\x64\x65stination_cidr_block\x18\x03 \x01(\t\x12\x11\n\tblackhole\x18\x04 \x01(\x08\x12%\n\x1dtransit_gateway_attachment_id\x18\x05 \x01(\t\"\xe3\x01\n\x18TransitGatewayRouteTable\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12transit_gateway_id\x18\x02 \x01(\t\x12\x45\n\x04tags\x18\x03 \x03(\x0b\x32\x37.oak9.tython.aws.ec2.TransitGatewayRouteTable.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xad\x01\n#TransitGatewayRouteTableAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1etransit_gateway_route_table_id\x18\x02 \x01(\t\x12%\n\x1dtransit_gateway_attachment_id\x18\x03 \x01(\t\"\xad\x01\n#TransitGatewayRouteTablePropagation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1etransit_gateway_route_table_id\x18\x02 \x01(\t\x12%\n\x1dtransit_gateway_attachment_id\x18\x03 \x01(\t\"\x94\x01\n\x14VPCGatewayAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13internet_gateway_id\x18\x02 \x01(\t\x12\x0e\n\x06vpc_id\x18\x03 \x01(\t\x12\x16\n\x0evpn_gateway_id\x18\x04 \x01(\t\"\x99\x01\n*VPNConnectionVpnTunnelOptionsSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0epre_shared_key\x18\x02 \x01(\t\x12\x1a\n\x12tunnel_inside_cidr\x18\x03 \x01(\t\"\x98\x03\n\rVPNConnection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63ustomer_gateway_id\x18\x02 \x01(\t\x12\x1a\n\x12static_routes_only\x18\x03 \x01(\x08\x12:\n\x04tags\x18\x04 \x03(\x0b\x32,.oak9.tython.aws.ec2.VPNConnection.TagsEntry\x12\x1a\n\x12transit_gateway_id\x18\x05 \x01(\t\x12\x0c\n\x04type\x18\x06 \x01(\t\x12\x16\n\x0evpn_gateway_id\x18\x07 \x01(\t\x12j\n!vpn_tunnel_options_specifications\x18\x08 \x03(\x0b\x32?.oak9.tython.aws.ec2.VPNConnectionVpnTunnelOptionsSpecification\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x88\x01\n\x12VPNConnectionRoute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x64\x65stination_cidr_block\x18\x02 \x01(\t\x12\x19\n\x11vpn_connection_id\x18\x03 \x01(\t\"\xd2\x01\n\nVPNGateway\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0f\x61mazon_side_asn\x18\x02 \x01(\x05\x12\x37\n\x04tags\x18\x03 \x03(\x0b\x32).oak9.tython.aws.ec2.VPNGateway.TagsEntry\x12\x0c\n\x04type\x18\x04 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x86\x01\n\x1aVPNGatewayRoutePropagation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0froute_table_ids\x18\x02 \x03(\t\x12\x16\n\x0evpn_gateway_id\x18\x03 \x01(\t\"\xf6\x02\n\x06Volume\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61uto_enable_io\x18\x02 \x01(\x08\x12\x19\n\x11\x61vailability_zone\x18\x03 \x01(\t\x12\x11\n\tencrypted\x18\x04 \x01(\x08\x12\x0c\n\x04iops\x18\x05 \x01(\x05\x12\x12\n\nkms_key_id\x18\x06 \x01(\t\x12\x1c\n\x14multi_attach_enabled\x18\x07 \x01(\x08\x12\x13\n\x0boutpost_arn\x18\x08 \x01(\t\x12\x0c\n\x04size\x18\t \x01(\x05\x12\x13\n\x0bsnapshot_id\x18\n \x01(\t\x12\x33\n\x04tags\x18\x0b \x03(\x0b\x32%.oak9.tython.aws.ec2.Volume.TagsEntry\x12\x13\n\x0bvolume_type\x18\x0c \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x83\x01\n\x10VolumeAttachment\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x13\n\x0binstance_id\x18\x03 \x01(\t\x12\x11\n\tvolume_id\x18\x04 \x01(\t\"s\n\x1cInstanceAssociationParameter\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x03(\t\"\xd9\x01\n\x0bInstanceEbs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x02 \x01(\x08\x12\x11\n\tencrypted\x18\x03 \x01(\x08\x12\x0c\n\x04iops\x18\x04 \x01(\x05\x12\x12\n\nkms_key_id\x18\x05 \x01(\t\x12\x13\n\x0bsnapshot_id\x18\x06 \x01(\t\x12\x13\n\x0bvolume_size\x18\x07 \x01(\x05\x12\x13\n\x0bvolume_type\x18\x08 \x01(\t\"K\n\x10InstanceNoDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xe9\x01\n\x1aInstanceBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12-\n\x03\x65\x62s\x18\x03 \x01(\x0b\x32 .oak9.tython.aws.ec2.InstanceEbs\x12\x38\n\tno_device\x18\x04 \x01(\x0b\x32%.oak9.tython.aws.ec2.InstanceNoDevice\x12\x14\n\x0cvirtual_name\x18\x05 \x01(\t\"{\n\x12InstanceCpuOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ncore_count\x18\x02 \x01(\x05\x12\x18\n\x10threads_per_core\x18\x03 \x01(\x05\"k\n\x1bInstanceCreditSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63pu_credits\x18\x02 \x01(\t\"Z\n\x1fInstanceElasticGpuSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"m\n#InstanceElasticInferenceAccelerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"i\n\x1aInstanceHibernationOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nconfigured\x18\x02 \x01(\x08\"l\n\x1bInstanceInstanceIpv6Address\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\"\xa9\x01\n#InstanceLaunchTemplateSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12launch_template_id\x18\x02 \x01(\t\x12\x1c\n\x14launch_template_name\x18\x03 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\"z\n\x1cInstanceLicenseSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19license_configuration_arn\x18\x02 \x01(\t\"\x8d\x01\n%InstancePrivateIpAddressSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07primary\x18\x02 \x01(\x08\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\"\x8e\x04\n\x18InstanceNetworkInterface\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1b\x61ssociate_public_ip_address\x18\x02 \x01(\x08\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x14\n\x0c\x64\x65vice_index\x18\x05 \x01(\t\x12\x11\n\tgroup_set\x18\x06 \x03(\t\x12\x1a\n\x12ipv6_address_count\x18\x07 \x01(\x05\x12H\n\x0eipv6_addresses\x18\x08 \x03(\x0b\x32\x30.oak9.tython.aws.ec2.InstanceInstanceIpv6Address\x12\x1c\n\x14network_interface_id\x18\t \x01(\t\x12\x1a\n\x12private_ip_address\x18\n \x01(\t\x12X\n\x14private_ip_addresses\x18\x0b \x03(\x0b\x32:.oak9.tython.aws.ec2.InstancePrivateIpAddressSpecification\x12*\n\"secondary_private_ip_address_count\x18\x0c \x01(\x05\x12\x11\n\tsubnet_id\x18\r \x01(\t\"\xbb\x01\n\x16InstanceSsmAssociation\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Q\n\x16\x61ssociation_parameters\x18\x02 \x03(\x0b\x32\x31.oak9.tython.aws.ec2.InstanceAssociationParameter\x12\x15\n\rdocument_name\x18\x03 \x01(\t\"l\n\x0eInstanceVolume\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x64\x65vice\x18\x02 \x01(\t\x12\x11\n\tvolume_id\x18\x03 \x01(\t\"\xdf\x01\n\x11LaunchTemplateEbs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsnapshot_id\x18\x02 \x01(\t\x12\x13\n\x0bvolume_type\x18\x03 \x01(\t\x12\x12\n\nkms_key_id\x18\x04 \x01(\t\x12\x11\n\tencrypted\x18\x05 \x01(\x08\x12\x0c\n\x04iops\x18\x06 \x01(\x05\x12\x13\n\x0bvolume_size\x18\x07 \x01(\x05\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x08 \x01(\x08\"\xce\x01\n LaunchTemplateBlockDeviceMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x33\n\x03\x65\x62s\x18\x02 \x01(\x0b\x32&.oak9.tython.aws.ec2.LaunchTemplateEbs\x12\x11\n\tno_device\x18\x03 \x01(\t\x12\x14\n\x0cvirtual_name\x18\x04 \x01(\t\x12\x13\n\x0b\x64\x65vice_name\x18\x05 \x01(\t\"\x83\x01\n\'LaunchTemplateCapacityReservationTarget\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1f\n\x17\x63\x61pacity_reservation_id\x18\x02 \x01(\t\"\xf5\x01\n.LaunchTemplateCapacityReservationSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\'\n\x1f\x63\x61pacity_reservation_preference\x18\x02 \x01(\t\x12\x61\n\x1b\x63\x61pacity_reservation_target\x18\x03 \x01(\x0b\x32<.oak9.tython.aws.ec2.LaunchTemplateCapacityReservationTarget\"\x81\x01\n\x18LaunchTemplateCpuOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10threads_per_core\x18\x02 \x01(\x05\x12\x12\n\ncore_count\x18\x03 \x01(\x05\"q\n!LaunchTemplateCreditSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x63pu_credits\x18\x02 \x01(\t\"`\n%LaunchTemplateElasticGpuSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"o\n LaunchTemplateHibernationOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nconfigured\x18\x02 \x01(\x08\"v\n LaunchTemplateIamInstanceProfile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61rn\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\xe0\x01\n\x19LaunchTemplateSpotOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12spot_instance_type\x18\x02 \x01(\t\x12&\n\x1einstance_interruption_behavior\x18\x03 \x01(\t\x12\x11\n\tmax_price\x18\x04 \x01(\t\x12\x1e\n\x16\x62lock_duration_minutes\x18\x05 \x01(\x05\x12\x13\n\x0bvalid_until\x18\x06 \x01(\t\"\xb9\x01\n#LaunchTemplateInstanceMarketOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x44\n\x0cspot_options\x18\x02 \x01(\x0b\x32..oak9.tython.aws.ec2.LaunchTemplateSpotOptions\x12\x13\n\x0bmarket_type\x18\x03 \x01(\t\"f\n\x15LaunchTemplateIpv6Add\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x14\n\x0cipv6_address\x18\x02 \x01(\t\"\xea\x01\n\x1eLaunchTemplateTagSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rresource_type\x18\x02 \x01(\t\x12K\n\x04tags\x18\x03 \x03(\x0b\x32=.oak9.tython.aws.ec2.LaunchTemplateTagSpecification.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x81\x01\n7LaunchTemplateLaunchTemplateElasticInferenceAccelerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x63ount\x18\x02 \x01(\x05\"\x87\x02\n\x17LaunchTemplatePlacement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\ngroup_name\x18\x02 \x01(\t\x12\x0f\n\x07tenancy\x18\x03 \x01(\t\x12\x15\n\rspread_domain\x18\x04 \x01(\t\x12\x18\n\x10partition_number\x18\x05 \x01(\x05\x12\x19\n\x11\x61vailability_zone\x18\x06 \x01(\t\x12\x10\n\x08\x61\x66\x66inity\x18\x07 \x01(\t\x12\x0f\n\x07host_id\x18\x08 \x01(\t\x12\x1f\n\x17host_resource_group_arn\x18\t \x01(\t\"\x82\x01\n\x1aLaunchTemplatePrivateIpAdd\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12private_ip_address\x18\x02 \x01(\t\x12\x0f\n\x07primary\x18\x03 \x01(\x08\"\x98\x04\n\x1eLaunchTemplateNetworkInterface\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x1a\n\x12private_ip_address\x18\x03 \x01(\t\x12M\n\x14private_ip_addresses\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.ec2.LaunchTemplatePrivateIpAdd\x12*\n\"secondary_private_ip_address_count\x18\x05 \x01(\x05\x12\x14\n\x0c\x64\x65vice_index\x18\x06 \x01(\x05\x12\x11\n\tsubnet_id\x18\x07 \x01(\t\x12\x42\n\x0eipv6_addresses\x18\x08 \x03(\x0b\x32*.oak9.tython.aws.ec2.LaunchTemplateIpv6Add\x12#\n\x1b\x61ssociate_public_ip_address\x18\t \x01(\x08\x12\x1c\n\x14network_interface_id\x18\n \x01(\t\x12\x16\n\x0einterface_type\x18\x0b \x01(\t\x12\x1a\n\x12ipv6_address_count\x18\x0c \x01(\x05\x12\x0e\n\x06groups\x18\r \x03(\t\x12\x1d\n\x15\x64\x65lete_on_termination\x18\x0e \x01(\x08\"d\n\x18LaunchTemplateMonitoring\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x65nabled\x18\x02 \x01(\x08\"\xa9\x01\n\x1dLaunchTemplateMetadataOptions\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12#\n\x1bhttp_put_response_hop_limit\x18\x02 \x01(\x05\x12\x13\n\x0bhttp_tokens\x18\x03 \x01(\t\x12\x15\n\rhttp_endpoint\x18\x04 \x01(\t\"\x80\x01\n\"LaunchTemplateLicenseSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19license_configuration_arn\x18\x02 \x01(\t\"\xf4\x0c\n LaunchTemplateLaunchTemplateData\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fsecurity_groups\x18\x02 \x03(\t\x12O\n\x12tag_specifications\x18\x03 \x03(\x0b\x32\x33.oak9.tython.aws.ec2.LaunchTemplateTagSpecification\x12\x11\n\tuser_data\x18\x04 \x01(\t\x12T\n\x15\x62lock_device_mappings\x18\x05 \x03(\x0b\x32\x35.oak9.tython.aws.ec2.LaunchTemplateBlockDeviceMapping\x12S\n\x14iam_instance_profile\x18\x06 \x01(\x0b\x32\x35.oak9.tython.aws.ec2.LaunchTemplateIamInstanceProfile\x12\x11\n\tkernel_id\x18\x07 \x01(\t\x12\x15\n\rebs_optimized\x18\x08 \x01(\x08\x12^\n\x1a\x65lastic_gpu_specifications\x18\t \x03(\x0b\x32:.oak9.tython.aws.ec2.LaunchTemplateElasticGpuSpecification\x12t\n\x1e\x65lastic_inference_accelerators\x18\n \x03(\x0b\x32L.oak9.tython.aws.ec2.LaunchTemplateLaunchTemplateElasticInferenceAccelerator\x12?\n\tplacement\x18\x0b \x01(\x0b\x32,.oak9.tython.aws.ec2.LaunchTemplatePlacement\x12O\n\x12network_interfaces\x18\x0c \x03(\x0b\x32\x33.oak9.tython.aws.ec2.LaunchTemplateNetworkInterface\x12\x10\n\x08image_id\x18\r \x01(\t\x12\x15\n\rinstance_type\x18\x0e \x01(\t\x12\x41\n\nmonitoring\x18\x0f \x01(\x0b\x32-.oak9.tython.aws.ec2.LaunchTemplateMonitoring\x12R\n\x13hibernation_options\x18\x10 \x01(\x0b\x32\x35.oak9.tython.aws.ec2.LaunchTemplateHibernationOptions\x12L\n\x10metadata_options\x18\x11 \x01(\x0b\x32\x32.oak9.tython.aws.ec2.LaunchTemplateMetadataOptions\x12W\n\x16license_specifications\x18\x12 \x03(\x0b\x32\x37.oak9.tython.aws.ec2.LaunchTemplateLicenseSpecification\x12,\n$instance_initiated_shutdown_behavior\x18\x13 \x01(\t\x12\x42\n\x0b\x63pu_options\x18\x14 \x01(\x0b\x32-.oak9.tython.aws.ec2.LaunchTemplateCpuOptions\x12\x1a\n\x12security_group_ids\x18\x15 \x03(\t\x12\x10\n\x08key_name\x18\x16 \x01(\t\x12\x1f\n\x17\x64isable_api_termination\x18\x17 \x01(\x08\x12Y\n\x17instance_market_options\x18\x18 \x01(\x0b\x32\x38.oak9.tython.aws.ec2.LaunchTemplateInstanceMarketOptions\x12\x13\n\x0bram_disk_id\x18\x19 \x01(\t\x12o\n\"capacity_reservation_specification\x18\x1a \x01(\x0b\x32\x43.oak9.tython.aws.ec2.LaunchTemplateCapacityReservationSpecification\x12T\n\x14\x63redit_specification\x18\x1b \x01(\x0b\x32\x36.oak9.tython.aws.ec2.LaunchTemplateCreditSpecification\"\\\n\x13NetworkAclEntryIcmp\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\"m\n\x18NetworkAclEntryPortRange\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x66rom\x18\x02 \x01(\x05\x12\n\n\x02to\x18\x03 \x01(\x05\"\x8b\x02\n\x13SecurityGroupEgress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x11\n\tcidr_ipv6\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\"\n\x1a\x64\x65stination_prefix_list_id\x18\x05 \x01(\t\x12%\n\x1d\x64\x65stination_security_group_id\x18\x06 \x01(\t\x12\x11\n\tfrom_port\x18\x07 \x01(\x05\x12\x13\n\x0bip_protocol\x18\x08 \x01(\t\x12\x0f\n\x07to_port\x18\t \x01(\x05\"\xce\x02\n\x14SecurityGroupIngress\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63idr_ip\x18\x02 \x01(\t\x12\x11\n\tcidr_ipv6\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x11\n\tfrom_port\x18\x05 \x01(\x05\x12\x13\n\x0bip_protocol\x18\x06 \x01(\t\x12\x1d\n\x15source_prefix_list_id\x18\x07 \x01(\t\x12 \n\x18source_security_group_id\x18\x08 \x01(\t\x12\"\n\x1asource_security_group_name\x18\t \x01(\t\x12&\n\x1esource_security_group_owner_id\x18\n \x01(\t\x12\x0f\n\x07to_port\x18\x0b \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ec2_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CAPACITYRESERVATIONTAGSPECIFICATION_TAGSENTRY._options = None
  _CAPACITYRESERVATIONTAGSPECIFICATION_TAGSENTRY._serialized_options = b'8\001'
  _CLIENTVPNENDPOINTTAGSPECIFICATION_TAGSENTRY._options = None
  _CLIENTVPNENDPOINTTAGSPECIFICATION_TAGSENTRY._serialized_options = b'8\001'
  _CUSTOMERGATEWAY_TAGSENTRY._options = None
  _CUSTOMERGATEWAY_TAGSENTRY._serialized_options = b'8\001'
  _EC2FLEETTAGSPECIFICATION_TAGSENTRY._options = None
  _EC2FLEETTAGSPECIFICATION_TAGSENTRY._serialized_options = b'8\001'
  _EIP_TAGSENTRY._options = None
  _EIP_TAGSENTRY._serialized_options = b'8\001'
  _FLOWLOG_TAGSENTRY._options = None
  _FLOWLOG_TAGSENTRY._serialized_options = b'8\001'
  _INTERNETGATEWAY_TAGSENTRY._options = None
  _INTERNETGATEWAY_TAGSENTRY._serialized_options = b'8\001'
  _LOCALGATEWAYROUTETABLEVPCASSOCIATIONTAGS_TAGSENTRY._options = None
  _LOCALGATEWAYROUTETABLEVPCASSOCIATIONTAGS_TAGSENTRY._serialized_options = b'8\001'
  _NATGATEWAY_TAGSENTRY._options = None
  _NATGATEWAY_TAGSENTRY._serialized_options = b'8\001'
  _NETWORKINTERFACE_TAGSENTRY._options = None
  _NETWORKINTERFACE_TAGSENTRY._serialized_options = b'8\001'
  _PREFIXLIST_TAGSENTRY._options = None
  _PREFIXLIST_TAGSENTRY._serialized_options = b'8\001'
  _SPOTFLEETSPOTFLEETTAGSPECIFICATION_TAGSENTRY._options = None
  _SPOTFLEETSPOTFLEETTAGSPECIFICATION_TAGSENTRY._serialized_options = b'8\001'
  _TRAFFICMIRRORFILTER_TAGSENTRY._options = None
  _TRAFFICMIRRORFILTER_TAGSENTRY._serialized_options = b'8\001'
  _TRAFFICMIRRORSESSION_TAGSENTRY._options = None
  _TRAFFICMIRRORSESSION_TAGSENTRY._serialized_options = b'8\001'
  _TRAFFICMIRRORTARGET_TAGSENTRY._options = None
  _TRAFFICMIRRORTARGET_TAGSENTRY._serialized_options = b'8\001'
  _TRANSITGATEWAY_TAGSENTRY._options = None
  _TRANSITGATEWAY_TAGSENTRY._serialized_options = b'8\001'
  _TRANSITGATEWAYATTACHMENT_TAGSENTRY._options = None
  _TRANSITGATEWAYATTACHMENT_TAGSENTRY._serialized_options = b'8\001'
  _TRANSITGATEWAYROUTETABLE_TAGSENTRY._options = None
  _TRANSITGATEWAYROUTETABLE_TAGSENTRY._serialized_options = b'8\001'
  _VPNCONNECTION_TAGSENTRY._options = None
  _VPNCONNECTION_TAGSENTRY._serialized_options = b'8\001'
  _VPNGATEWAY_TAGSENTRY._options = None
  _VPNGATEWAY_TAGSENTRY._serialized_options = b'8\001'
  _VOLUME_TAGSENTRY._options = None
  _VOLUME_TAGSENTRY._serialized_options = b'8\001'
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._options = None
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_options = b'8\001'
  _CAPACITYRESERVATIONTAGSPECIFICATION._serialized_start=64
  _CAPACITYRESERVATIONTAGSPECIFICATION._serialized_end=308
  _CAPACITYRESERVATIONTAGSPECIFICATION_TAGSENTRY._serialized_start=265
  _CAPACITYRESERVATIONTAGSPECIFICATION_TAGSENTRY._serialized_end=308
  _CAPACITYRESERVATION._serialized_start=311
  _CAPACITYRESERVATION._serialized_end=717
  _EC2._serialized_start=720
  _EC2._serialized_end=6050
  _CLIENTVPNAUTHORIZATIONRULE._serialized_start=6053
  _CLIENTVPNAUTHORIZATIONRULE._serialized_end=6275
  _CLIENTVPNENDPOINTCONNECTIONLOGOPTIONS._serialized_start=6278
  _CLIENTVPNENDPOINTCONNECTIONLOGOPTIONS._serialized_end=6452
  _CLIENTVPNENDPOINTTAGSPECIFICATION._serialized_start=6455
  _CLIENTVPNENDPOINTTAGSPECIFICATION._serialized_end=6695
  _CLIENTVPNENDPOINTTAGSPECIFICATION_TAGSENTRY._serialized_start=265
  _CLIENTVPNENDPOINTTAGSPECIFICATION_TAGSENTRY._serialized_end=308
  _CLIENTVPNENDPOINTCERTIFICATEAUTHENTICATIONREQUEST._serialized_start=6698
  _CLIENTVPNENDPOINTCERTIFICATEAUTHENTICATIONREQUEST._serialized_end=6849
  _CLIENTVPNENDPOINTFEDERATEDAUTHENTICATIONREQUEST._serialized_start=6852
  _CLIENTVPNENDPOINTFEDERATEDAUTHENTICATIONREQUEST._serialized_end=6985
  _CLIENTVPNENDPOINTDIRECTORYSERVICEAUTHENTICATIONREQUEST._serialized_start=6988
  _CLIENTVPNENDPOINTDIRECTORYSERVICEAUTHENTICATIONREQUEST._serialized_end=7123
  _CLIENTVPNENDPOINTCLIENTAUTHENTICATIONREQUEST._serialized_start=7126
  _CLIENTVPNENDPOINTCLIENTAUTHENTICATIONREQUEST._serialized_end=7539
  _CLIENTVPNENDPOINT._serialized_start=7542
  _CLIENTVPNENDPOINT._serialized_end=8106
  _CLIENTVPNROUTE._serialized_start=8109
  _CLIENTVPNROUTE._serialized_end=8297
  _CLIENTVPNTARGETNETWORKASSOCIATION._serialized_start=8300
  _CLIENTVPNTARGETNETWORKASSOCIATION._serialized_end=8443
  _CUSTOMERGATEWAY._serialized_start=8446
  _CUSTOMERGATEWAY._serialized_end=8678
  _CUSTOMERGATEWAY_TAGSENTRY._serialized_start=265
  _CUSTOMERGATEWAY_TAGSENTRY._serialized_end=308
  _EC2FLEETTARGETCAPACITYSPECIFICATIONREQUEST._serialized_start=8681
  _EC2FLEETTARGETCAPACITYSPECIFICATIONREQUEST._serialized_end=8916
  _EC2FLEETCAPACITYRESERVATIONOPTIONSREQUEST._serialized_start=8918
  _EC2FLEETCAPACITYRESERVATIONOPTIONSREQUEST._serialized_end=9042
  _EC2FLEETONDEMANDOPTIONSREQUEST._serialized_start=9045
  _EC2FLEETONDEMANDOPTIONSREQUEST._serialized_end=9383
  _EC2FLEETTAGSPECIFICATION._serialized_start=9386
  _EC2FLEETTAGSPECIFICATION._serialized_end=9608
  _EC2FLEETTAGSPECIFICATION_TAGSENTRY._serialized_start=265
  _EC2FLEETTAGSPECIFICATION_TAGSENTRY._serialized_end=308
  _EC2FLEETSPOTOPTIONSREQUEST._serialized_start=9611
  _EC2FLEETSPOTOPTIONSREQUEST._serialized_end=9920
  _EC2FLEETFLEETLAUNCHTEMPLATESPECIFICATIONREQUEST._serialized_start=9923
  _EC2FLEETFLEETLAUNCHTEMPLATESPECIFICATIONREQUEST._serialized_end=10104
  _EC2FLEETPLACEMENT._serialized_start=10107
  _EC2FLEETPLACEMENT._serialized_end=10364
  _EC2FLEETFLEETLAUNCHTEMPLATEOVERRIDESREQUEST._serialized_start=10367
  _EC2FLEETFLEETLAUNCHTEMPLATEOVERRIDESREQUEST._serialized_end=10661
  _EC2FLEETFLEETLAUNCHTEMPLATECONFIGREQUEST._serialized_start=10664
  _EC2FLEETFLEETLAUNCHTEMPLATECONFIGREQUEST._serialized_end=10957
  _EC2FLEET._serialized_start=10960
  _EC2FLEET._serialized_end=11634
  _EIP._serialized_start=11637
  _EIP._serialized_end=11857
  _EIP_TAGSENTRY._serialized_start=265
  _EIP_TAGSENTRY._serialized_end=308
  _EIPASSOCIATION._serialized_start=11860
  _EIPASSOCIATION._serialized_end=12049
  _EGRESSONLYINTERNETGATEWAY._serialized_start=12051
  _EGRESSONLYINTERNETGATEWAY._serialized_end=12151
  _FLOWLOG._serialized_start=12154
  _FLOWLOG._serialized_end=12555
  _FLOWLOG_TAGSENTRY._serialized_start=265
  _FLOWLOG_TAGSENTRY._serialized_end=308
  _GATEWAYROUTETABLEASSOCIATION._serialized_start=12558
  _GATEWAYROUTETABLEASSOCIATION._serialized_end=12689
  _HOST._serialized_start=12692
  _HOST._serialized_end=12852
  _INTERNETGATEWAY._serialized_start=12855
  _INTERNETGATEWAY._serialized_end=13036
  _INTERNETGATEWAY_TAGSENTRY._serialized_start=265
  _INTERNETGATEWAY_TAGSENTRY._serialized_end=308
  _LOCALGATEWAYROUTE._serialized_start=13039
  _LOCALGATEWAYROUTE._serialized_end=13235
  _LOCALGATEWAYROUTETABLEVPCASSOCIATIONTAGS._serialized_start=13238
  _LOCALGATEWAYROUTETABLEVPCASSOCIATIONTAGS._serialized_end=13469
  _LOCALGATEWAYROUTETABLEVPCASSOCIATIONTAGS_TAGSENTRY._serialized_start=265
  _LOCALGATEWAYROUTETABLEVPCASSOCIATIONTAGS_TAGSENTRY._serialized_end=308
  _LOCALGATEWAYROUTETABLEVPCASSOCIATION._serialized_start=13472
  _LOCALGATEWAYROUTETABLEVPCASSOCIATION._serialized_end=13698
  _NATGATEWAY._serialized_start=13701
  _NATGATEWAY._serialized_end=13914
  _NATGATEWAY_TAGSENTRY._serialized_start=265
  _NATGATEWAY_TAGSENTRY._serialized_end=308
  _NETWORKINTERFACEINSTANCEIPV6ADDRESS._serialized_start=13916
  _NETWORKINTERFACEINSTANCEIPV6ADDRESS._serialized_end=14032
  _NETWORKINTERFACEPRIVATEIPADDRESSSPECIFICATION._serialized_start=14035
  _NETWORKINTERFACEPRIVATEIPADDRESSSPECIFICATION._serialized_end=14184
  _NETWORKINTERFACE._serialized_start=14187
  _NETWORKINTERFACE._serialized_end=14760
  _NETWORKINTERFACE_TAGSENTRY._serialized_start=265
  _NETWORKINTERFACE_TAGSENTRY._serialized_end=308
  _NETWORKINTERFACEATTACHMENT._serialized_start=14763
  _NETWORKINTERFACEATTACHMENT._serialized_end=14952
  _NETWORKINTERFACEPERMISSION._serialized_start=14955
  _NETWORKINTERFACEPERMISSION._serialized_end=15114
  _PLACEMENTGROUP._serialized_start=15116
  _PLACEMENTGROUP._serialized_end=15207
  _PREFIXLISTENTRY._serialized_start=15209
  _PREFIXLISTENTRY._serialized_end=15318
  _PREFIXLIST._serialized_start=15321
  _PREFIXLIST._serialized_end=15618
  _PREFIXLIST_TAGSENTRY._serialized_start=265
  _PREFIXLIST_TAGSENTRY._serialized_end=308
  _SPOTFLEETEBSBLOCKDEVICE._serialized_start=15621
  _SPOTFLEETEBSBLOCKDEVICE._serialized_end=15830
  _SPOTFLEETBLOCKDEVICEMAPPING._serialized_start=15833
  _SPOTFLEETBLOCKDEVICEMAPPING._serialized_end=16040
  _SPOTFLEETIAMINSTANCEPROFILESPECIFICATION._serialized_start=16042
  _SPOTFLEETIAMINSTANCEPROFILESPECIFICATION._serialized_end=16154
  _SPOTFLEETSPOTFLEETMONITORING._serialized_start=16156
  _SPOTFLEETSPOTFLEETMONITORING._serialized_end=16260
  _SPOTFLEETINSTANCEIPV6ADDRESS._serialized_start=16262
  _SPOTFLEETINSTANCEIPV6ADDRESS._serialized_end=16371
  _SPOTFLEETPRIVATEIPADDRESSSPECIFICATION._serialized_start=16374
  _SPOTFLEETPRIVATEIPADDRESSSPECIFICATION._serialized_end=16516
  _SPOTFLEETINSTANCENETWORKINTERFACESPECIFICATION._serialized_start=16519
  _SPOTFLEETINSTANCENETWORKINTERFACESPECIFICATION._serialized_end=17038
  _SPOTFLEETSPOTPLACEMENT._serialized_start=17041
  _SPOTFLEETSPOTPLACEMENT._serialized_end=17186
  _SPOTFLEETGROUPIDENTIFIER._serialized_start=17188
  _SPOTFLEETGROUPIDENTIFIER._serialized_end=17289
  _SPOTFLEETSPOTFLEETTAGSPECIFICATION._serialized_start=17292
  _SPOTFLEETSPOTFLEETTAGSPECIFICATION._serialized_end=17534
  _SPOTFLEETSPOTFLEETTAGSPECIFICATION_TAGSENTRY._serialized_start=265
  _SPOTFLEETSPOTFLEETTAGSPECIFICATION_TAGSENTRY._serialized_end=308
  _SPOTFLEETSPOTFLEETLAUNCHSPECIFICATION._serialized_start=17537
  _SPOTFLEETSPOTFLEETLAUNCHSPECIFICATION._serialized_end=18402
  _SPOTFLEETFLEETLAUNCHTEMPLATESPECIFICATION._serialized_start=18405
  _SPOTFLEETFLEETLAUNCHTEMPLATESPECIFICATION._serialized_end=18580
  _SPOTFLEETLAUNCHTEMPLATEOVERRIDES._serialized_start=18583
  _SPOTFLEETLAUNCHTEMPLATEOVERRIDES._serialized_end=18790
  _SPOTFLEETLAUNCHTEMPLATECONFIG._serialized_start=18793
  _SPOTFLEETLAUNCHTEMPLATECONFIG._serialized_end=19058
  _SPOTFLEETCLASSICLOADBALANCER._serialized_start=19060
  _SPOTFLEETCLASSICLOADBALANCER._serialized_end=19161
  _SPOTFLEETCLASSICLOADBALANCERSCONFIG._serialized_start=19164
  _SPOTFLEETCLASSICLOADBALANCERSCONFIG._serialized_end=19341
  _SPOTFLEETTARGETGROUP._serialized_start=19343
  _SPOTFLEETTARGETGROUP._serialized_end=19435
  _SPOTFLEETTARGETGROUPSCONFIG._serialized_start=19438
  _SPOTFLEETTARGETGROUPSCONFIG._serialized_end=19590
  _SPOTFLEETLOADBALANCERSCONFIG._serialized_start=19593
  _SPOTFLEETLOADBALANCERSCONFIG._serialized_end=19857
  _SPOTFLEETSPOTFLEETREQUESTCONFIGDATA._serialized_start=19860
  _SPOTFLEETSPOTFLEETREQUESTCONFIGDATA._serialized_end=20517
  _SPOTFLEET._serialized_start=20520
  _SPOTFLEET._serialized_end=20686
  _TRAFFICMIRRORFILTER._serialized_start=20689
  _TRAFFICMIRRORFILTER._serialized_end=20925
  _TRAFFICMIRRORFILTER_TAGSENTRY._serialized_start=265
  _TRAFFICMIRRORFILTER_TAGSENTRY._serialized_end=308
  _TRAFFICMIRRORFILTERRULETRAFFICMIRRORPORTRANGE._serialized_start=20928
  _TRAFFICMIRRORFILTERRULETRAFFICMIRRORPORTRANGE._serialized_end=21068
  _TRAFFICMIRRORFILTERRULE._serialized_start=21071
  _TRAFFICMIRRORFILTERRULE._serialized_end=21549
  _TRAFFICMIRRORSESSION._serialized_start=21552
  _TRAFFICMIRRORSESSION._serialized_end=21937
  _TRAFFICMIRRORSESSION_TAGSENTRY._serialized_start=265
  _TRAFFICMIRRORSESSION_TAGSENTRY._serialized_end=308
  _TRAFFICMIRRORTARGET._serialized_start=21940
  _TRAFFICMIRRORTARGET._serialized_end=22215
  _TRAFFICMIRRORTARGET_TAGSENTRY._serialized_start=265
  _TRAFFICMIRRORTARGET_TAGSENTRY._serialized_end=308
  _TRANSITGATEWAY._serialized_start=22218
  _TRANSITGATEWAY._serialized_end=22639
  _TRANSITGATEWAY_TAGSENTRY._serialized_start=265
  _TRANSITGATEWAY_TAGSENTRY._serialized_end=308
  _TRANSITGATEWAYATTACHMENT._serialized_start=22642
  _TRANSITGATEWAYATTACHMENT._serialized_end=22905
  _TRANSITGATEWAYATTACHMENT_TAGSENTRY._serialized_start=265
  _TRANSITGATEWAYATTACHMENT_TAGSENTRY._serialized_end=308
  _TRANSITGATEWAYROUTE._serialized_start=22908
  _TRANSITGATEWAYROUTE._serialized_end=23116
  _TRANSITGATEWAYROUTETABLE._serialized_start=23119
  _TRANSITGATEWAYROUTETABLE._serialized_end=23346
  _TRANSITGATEWAYROUTETABLE_TAGSENTRY._serialized_start=265
  _TRANSITGATEWAYROUTETABLE_TAGSENTRY._serialized_end=308
  _TRANSITGATEWAYROUTETABLEASSOCIATION._serialized_start=23349
  _TRANSITGATEWAYROUTETABLEASSOCIATION._serialized_end=23522
  _TRANSITGATEWAYROUTETABLEPROPAGATION._serialized_start=23525
  _TRANSITGATEWAYROUTETABLEPROPAGATION._serialized_end=23698
  _VPCGATEWAYATTACHMENT._serialized_start=23701
  _VPCGATEWAYATTACHMENT._serialized_end=23849
  _VPNCONNECTIONVPNTUNNELOPTIONSSPECIFICATION._serialized_start=23852
  _VPNCONNECTIONVPNTUNNELOPTIONSSPECIFICATION._serialized_end=24005
  _VPNCONNECTION._serialized_start=24008
  _VPNCONNECTION._serialized_end=24416
  _VPNCONNECTION_TAGSENTRY._serialized_start=265
  _VPNCONNECTION_TAGSENTRY._serialized_end=308
  _VPNCONNECTIONROUTE._serialized_start=24419
  _VPNCONNECTIONROUTE._serialized_end=24555
  _VPNGATEWAY._serialized_start=24558
  _VPNGATEWAY._serialized_end=24768
  _VPNGATEWAY_TAGSENTRY._serialized_start=265
  _VPNGATEWAY_TAGSENTRY._serialized_end=308
  _VPNGATEWAYROUTEPROPAGATION._serialized_start=24771
  _VPNGATEWAYROUTEPROPAGATION._serialized_end=24905
  _VOLUME._serialized_start=24908
  _VOLUME._serialized_end=25282
  _VOLUME_TAGSENTRY._serialized_start=265
  _VOLUME_TAGSENTRY._serialized_end=308
  _VOLUMEATTACHMENT._serialized_start=25285
  _VOLUMEATTACHMENT._serialized_end=25416
  _INSTANCEASSOCIATIONPARAMETER._serialized_start=25418
  _INSTANCEASSOCIATIONPARAMETER._serialized_end=25533
  _INSTANCEEBS._serialized_start=25536
  _INSTANCEEBS._serialized_end=25753
  _INSTANCENODEVICE._serialized_start=25755
  _INSTANCENODEVICE._serialized_end=25830
  _INSTANCEBLOCKDEVICEMAPPING._serialized_start=25833
  _INSTANCEBLOCKDEVICEMAPPING._serialized_end=26066
  _INSTANCECPUOPTIONS._serialized_start=26068
  _INSTANCECPUOPTIONS._serialized_end=26191
  _INSTANCECREDITSPECIFICATION._serialized_start=26193
  _INSTANCECREDITSPECIFICATION._serialized_end=26300
  _INSTANCEELASTICGPUSPECIFICATION._serialized_start=26302
  _INSTANCEELASTICGPUSPECIFICATION._serialized_end=26392
  _INSTANCEELASTICINFERENCEACCELERATOR._serialized_start=26394
  _INSTANCEELASTICINFERENCEACCELERATOR._serialized_end=26503
  _INSTANCEHIBERNATIONOPTIONS._serialized_start=26505
  _INSTANCEHIBERNATIONOPTIONS._serialized_end=26610
  _INSTANCEINSTANCEIPV6ADDRESS._serialized_start=26612
  _INSTANCEINSTANCEIPV6ADDRESS._serialized_end=26720
  _INSTANCELAUNCHTEMPLATESPECIFICATION._serialized_start=26723
  _INSTANCELAUNCHTEMPLATESPECIFICATION._serialized_end=26892
  _INSTANCELICENSESPECIFICATION._serialized_start=26894
  _INSTANCELICENSESPECIFICATION._serialized_end=27016
  _INSTANCEPRIVATEIPADDRESSSPECIFICATION._serialized_start=27019
  _INSTANCEPRIVATEIPADDRESSSPECIFICATION._serialized_end=27160
  _INSTANCENETWORKINTERFACE._serialized_start=27163
  _INSTANCENETWORKINTERFACE._serialized_end=27689
  _INSTANCESSMASSOCIATION._serialized_start=27692
  _INSTANCESSMASSOCIATION._serialized_end=27879
  _INSTANCEVOLUME._serialized_start=27881
  _INSTANCEVOLUME._serialized_end=27989
  _LAUNCHTEMPLATEEBS._serialized_start=27992
  _LAUNCHTEMPLATEEBS._serialized_end=28215
  _LAUNCHTEMPLATEBLOCKDEVICEMAPPING._serialized_start=28218
  _LAUNCHTEMPLATEBLOCKDEVICEMAPPING._serialized_end=28424
  _LAUNCHTEMPLATECAPACITYRESERVATIONTARGET._serialized_start=28427
  _LAUNCHTEMPLATECAPACITYRESERVATIONTARGET._serialized_end=28558
  _LAUNCHTEMPLATECAPACITYRESERVATIONSPECIFICATION._serialized_start=28561
  _LAUNCHTEMPLATECAPACITYRESERVATIONSPECIFICATION._serialized_end=28806
  _LAUNCHTEMPLATECPUOPTIONS._serialized_start=28809
  _LAUNCHTEMPLATECPUOPTIONS._serialized_end=28938
  _LAUNCHTEMPLATECREDITSPECIFICATION._serialized_start=28940
  _LAUNCHTEMPLATECREDITSPECIFICATION._serialized_end=29053
  _LAUNCHTEMPLATEELASTICGPUSPECIFICATION._serialized_start=29055
  _LAUNCHTEMPLATEELASTICGPUSPECIFICATION._serialized_end=29151
  _LAUNCHTEMPLATEHIBERNATIONOPTIONS._serialized_start=29153
  _LAUNCHTEMPLATEHIBERNATIONOPTIONS._serialized_end=29264
  _LAUNCHTEMPLATEIAMINSTANCEPROFILE._serialized_start=29266
  _LAUNCHTEMPLATEIAMINSTANCEPROFILE._serialized_end=29384
  _LAUNCHTEMPLATESPOTOPTIONS._serialized_start=29387
  _LAUNCHTEMPLATESPOTOPTIONS._serialized_end=29611
  _LAUNCHTEMPLATEINSTANCEMARKETOPTIONS._serialized_start=29614
  _LAUNCHTEMPLATEINSTANCEMARKETOPTIONS._serialized_end=29799
  _LAUNCHTEMPLATEIPV6ADD._serialized_start=29801
  _LAUNCHTEMPLATEIPV6ADD._serialized_end=29903
  _LAUNCHTEMPLATETAGSPECIFICATION._serialized_start=29906
  _LAUNCHTEMPLATETAGSPECIFICATION._serialized_end=30140
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_start=265
  _LAUNCHTEMPLATETAGSPECIFICATION_TAGSENTRY._serialized_end=308
  _LAUNCHTEMPLATELAUNCHTEMPLATEELASTICINFERENCEACCELERATOR._serialized_start=30143
  _LAUNCHTEMPLATELAUNCHTEMPLATEELASTICINFERENCEACCELERATOR._serialized_end=30272
  _LAUNCHTEMPLATEPLACEMENT._serialized_start=30275
  _LAUNCHTEMPLATEPLACEMENT._serialized_end=30538
  _LAUNCHTEMPLATEPRIVATEIPADD._serialized_start=30541
  _LAUNCHTEMPLATEPRIVATEIPADD._serialized_end=30671
  _LAUNCHTEMPLATENETWORKINTERFACE._serialized_start=30674
  _LAUNCHTEMPLATENETWORKINTERFACE._serialized_end=31210
  _LAUNCHTEMPLATEMONITORING._serialized_start=31212
  _LAUNCHTEMPLATEMONITORING._serialized_end=31312
  _LAUNCHTEMPLATEMETADATAOPTIONS._serialized_start=31315
  _LAUNCHTEMPLATEMETADATAOPTIONS._serialized_end=31484
  _LAUNCHTEMPLATELICENSESPECIFICATION._serialized_start=31487
  _LAUNCHTEMPLATELICENSESPECIFICATION._serialized_end=31615
  _LAUNCHTEMPLATELAUNCHTEMPLATEDATA._serialized_start=31618
  _LAUNCHTEMPLATELAUNCHTEMPLATEDATA._serialized_end=33270
  _NETWORKACLENTRYICMP._serialized_start=33272
  _NETWORKACLENTRYICMP._serialized_end=33364
  _NETWORKACLENTRYPORTRANGE._serialized_start=33366
  _NETWORKACLENTRYPORTRANGE._serialized_end=33475
  _SECURITYGROUPEGRESS._serialized_start=33478
  _SECURITYGROUPEGRESS._serialized_end=33745
  _SECURITYGROUPINGRESS._serialized_start=33748
  _SECURITYGROUPINGRESS._serialized_end=34082
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_compute_health.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1cgcp/gcp_compute_health.proto\x12\x1eoak9.tython.gcp.compute_health\x1a\x13shared/shared.proto\"|\n\"ComputeHealthCheckXGrpcHealthCheck\x12\x19\n\x11grpc_service_name\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\x12\x11\n\tport_name\x18\x03 \x01(\t\x12\x1a\n\x12port_specification\x18\x04 \x01(\t\"\xae\x01\n#ComputeHealthCheckXHttp2HealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\x12\x11\n\tport_name\x18\x03 \x01(\t\x12\x1a\n\x12port_specification\x18\x04 \x01(\t\x12\x14\n\x0cproxy_header\x18\x05 \x01(\t\x12\x14\n\x0crequest_path\x18\x06 \x01(\t\x12\x10\n\x08response\x18\x07 \x01(\t\"\xad\x01\n\"ComputeHealthCheckXHttpHealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\x12\x11\n\tport_name\x18\x03 \x01(\t\x12\x1a\n\x12port_specification\x18\x04 \x01(\t\x12\x14\n\x0cproxy_header\x18\x05 \x01(\t\x12\x14\n\x0crequest_path\x18\x06 \x01(\t\x12\x10\n\x08response\x18\x07 \x01(\t\"\xae\x01\n#ComputeHealthCheckXHttpsHealthCheck\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x01\x12\x11\n\tport_name\x18\x03 \x01(\t\x12\x1a\n\x12port_specification\x18\x04 \x01(\t\x12\x14\n\x0cproxy_header\x18\x05 \x01(\t\x12\x14\n\x0crequest_path\x18\x06 \x01(\t\x12\x10\n\x08response\x18\x07 \x01(\t\".\n\x1c\x43omputeHealthCheckXLogConfig\x12\x0e\n\x06\x65nable\x18\x01 \x01(\x08\"\x99\x01\n!ComputeHealthCheckXSslHealthCheck\x12\x0c\n\x04port\x18\x01 \x01(\x01\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x1a\n\x12port_specification\x18\x03 \x01(\t\x12\x14\n\x0cproxy_header\x18\x04 \x01(\t\x12\x0f\n\x07request\x18\x05 \x01(\t\x12\x10\n\x08response\x18\x06 \x01(\t\"\x99\x01\n!ComputeHealthCheckXTcpHealthCheck\x12\x0c\n\x04port\x18\x01 \x01(\x01\x12\x11\n\tport_name\x18\x02 \x01(\t\x12\x1a\n\x12port_specification\x18\x03 \x01(\t\x12\x14\n\x0cproxy_header\x18\x04 \x01(\t\x12\x0f\n\x07request\x18\x05 \x01(\t\x12\x10\n\x08response\x18\x06 \x01(\t\"M\n\x1b\x43omputeHealthCheckXTimeouts\x12\x0e\n\x06\x63reate\x18\x01 \x01(\t\x12\x0e\n\x06\x64\x65lete\x18\x02 \x01(\t\x12\x0e\n\x06update\x18\x03 \x01(\t\"\x8e\x08\n\x12\x43omputeHealthCheck\x12\x1a\n\x12\x63heck_interval_sec\x18\x01 \x01(\x01\x12\x1a\n\x12\x63reation_timestamp\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11healthy_threshold\x18\x04 \x01(\x01\x12\n\n\x02id\x18\x05 \x01(\t\x12\x0c\n\x04name\x18\x06 \x01(\t\x12\x0f\n\x07project\x18\x07 \x01(\t\x12\x11\n\tself_link\x18\x08 \x01(\t\x12\x13\n\x0btimeout_sec\x18\t \x01(\x01\x12\x0c\n\x04type\x18\n \x01(\t\x12\x1b\n\x13unhealthy_threshold\x18\x0b \x01(\x01\x12]\n\x11grpc_health_check\x18\x0c \x01(\x0b\x32\x42.oak9.tython.gcp.compute_health.ComputeHealthCheckXGrpcHealthCheck\x12_\n\x12http2_health_check\x18\r \x01(\x0b\x32\x43.oak9.tython.gcp.compute_health.ComputeHealthCheckXHttp2HealthCheck\x12]\n\x11http_health_check\x18\x0e \x01(\x0b\x32\x42.oak9.tython.gcp.compute_health.ComputeHealthCheckXHttpHealthCheck\x12_\n\x12https_health_check\x18\x0f \x01(\x0b\x32\x43.oak9.tython.gcp.compute_health.ComputeHealthCheckXHttpsHealthCheck\x12P\n\nlog_config\x18\x10 \x01(\x0b\x32<.oak9.tython.gcp.compute_health.ComputeHealthCheckXLogConfig\x12[\n\x10ssl_health_check\x18\x11 \x01(\x0b\x32\x41.oak9.tython.gcp.compute_health.ComputeHealthCheckXSslHealthCheck\x12[\n\x10tcp_health_check\x18\x12 \x01(\x0b\x32\x41.oak9.tython.gcp.compute_health.ComputeHealthCheckXTcpHealthCheck\x12M\n\x08timeouts\x18\x13 \x01(\x0b\x32;.oak9.tython.gcp.compute_health.ComputeHealthCheckXTimeouts\x12\x37\n\rresource_info\x18\x14 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_compute_health_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMPUTEHEALTHCHECKXGRPCHEALTHCHECK._serialized_start=85
  _COMPUTEHEALTHCHECKXGRPCHEALTHCHECK._serialized_end=209
  _COMPUTEHEALTHCHECKXHTTP2HEALTHCHECK._serialized_start=212
  _COMPUTEHEALTHCHECKXHTTP2HEALTHCHECK._serialized_end=386
  _COMPUTEHEALTHCHECKXHTTPHEALTHCHECK._serialized_start=389
  _COMPUTEHEALTHCHECKXHTTPHEALTHCHECK._serialized_end=562
  _COMPUTEHEALTHCHECKXHTTPSHEALTHCHECK._serialized_start=565
  _COMPUTEHEALTHCHECKXHTTPSHEALTHCHECK._serialized_end=739
  _COMPUTEHEALTHCHECKXLOGCONFIG._serialized_start=741
  _COMPUTEHEALTHCHECKXLOGCONFIG._serialized_end=787
  _COMPUTEHEALTHCHECKXSSLHEALTHCHECK._serialized_start=790
  _COMPUTEHEALTHCHECKXSSLHEALTHCHECK._serialized_end=943
  _COMPUTEHEALTHCHECKXTCPHEALTHCHECK._serialized_start=946
  _COMPUTEHEALTHCHECKXTCPHEALTHCHECK._serialized_end=1099
  _COMPUTEHEALTHCHECKXTIMEOUTS._serialized_start=1101
  _COMPUTEHEALTHCHECKXTIMEOUTS._serialized_end=1178
  _COMPUTEHEALTHCHECK._serialized_start=1181
  _COMPUTEHEALTHCHECK._serialized_end=2219
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_robomaker.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17\x61ws/aws_robomaker.proto\x12\x19oak9.tython.aws.robomaker\x1a\x13shared/shared.proto\"\xb5\x01\n\x05\x46leet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x38\n\x04tags\x18\x02 \x03(\x0b\x32*.oak9.tython.aws.robomaker.Fleet.TagsEntry\x12\x0c\n\x04name\x18\x03 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbf\x03\n\tRoboMaker\x12/\n\x05\x66leet\x18\x01 \x03(\x0b\x32 .oak9.tython.aws.robomaker.Fleet\x12/\n\x05robot\x18\x02 \x03(\x0b\x32 .oak9.tython.aws.robomaker.Robot\x12\x46\n\x11robot_application\x18\x03 \x03(\x0b\x32+.oak9.tython.aws.robomaker.RobotApplication\x12U\n\x19robot_application_version\x18\x04 \x03(\x0b\x32\x32.oak9.tython.aws.robomaker.RobotApplicationVersion\x12P\n\x16simulation_application\x18\x05 \x03(\x0b\x32\x30.oak9.tython.aws.robomaker.SimulationApplication\x12_\n\x1esimulation_application_version\x18\x06 \x03(\x0b\x32\x37.oak9.tython.aws.robomaker.SimulationApplicationVersion\"\xf7\x01\n\x05Robot\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x66leet\x18\x02 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x03 \x01(\t\x12\x1b\n\x13greengrass_group_id\x18\x04 \x01(\t\x12\x38\n\x04tags\x18\x05 \x03(\x0b\x32*.oak9.tython.aws.robomaker.Robot.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"|\n\"RobotApplicationRobotSoftwareSuite\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x90\x01\n\x1cRobotApplicationSourceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x03 \x01(\t\x12\x0e\n\x06s3_key\x18\x04 \x01(\t\"\x8f\x03\n\x10RobotApplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63urrent_revision_id\x18\x02 \x01(\t\x12[\n\x14robot_software_suite\x18\x03 \x01(\x0b\x32=.oak9.tython.aws.robomaker.RobotApplicationRobotSoftwareSuite\x12H\n\x07sources\x18\x04 \x03(\x0b\x32\x37.oak9.tython.aws.robomaker.RobotApplicationSourceConfig\x12\x43\n\x04tags\x18\x05 \x03(\x0b\x32\x35.oak9.tython.aws.robomaker.RobotApplication.TagsEntry\x12\x0c\n\x04name\x18\x06 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x84\x01\n\x17RobotApplicationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63urrent_revision_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\t\"~\n$SimulationApplicationRenderingEngine\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x86\x01\n,SimulationApplicationSimulationSoftwareSuite\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x81\x01\n\'SimulationApplicationRobotSoftwareSuite\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\"\x95\x01\n!SimulationApplicationSourceConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\ts3_bucket\x18\x02 \x01(\t\x12\x14\n\x0c\x61rchitecture\x18\x03 \x01(\t\x12\x0e\n\x06s3_key\x18\x04 \x01(\t\"\xea\x04\n\x15SimulationApplication\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12Y\n\x10rendering_engine\x18\x02 \x01(\x0b\x32?.oak9.tython.aws.robomaker.SimulationApplicationRenderingEngine\x12j\n\x19simulation_software_suite\x18\x03 \x01(\x0b\x32G.oak9.tython.aws.robomaker.SimulationApplicationSimulationSoftwareSuite\x12\x1b\n\x13\x63urrent_revision_id\x18\x04 \x01(\t\x12`\n\x14robot_software_suite\x18\x05 \x01(\x0b\x32\x42.oak9.tython.aws.robomaker.SimulationApplicationRobotSoftwareSuite\x12M\n\x07sources\x18\x06 \x03(\x0b\x32<.oak9.tython.aws.robomaker.SimulationApplicationSourceConfig\x12H\n\x04tags\x18\x07 \x03(\x0b\x32:.oak9.tython.aws.robomaker.SimulationApplication.TagsEntry\x12\x0c\n\x04name\x18\x08 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x89\x01\n\x1cSimulationApplicationVersion\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13\x63urrent_revision_id\x18\x02 \x01(\t\x12\x13\n\x0b\x61pplication\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_robomaker_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _FLEET_TAGSENTRY._options = None
  _FLEET_TAGSENTRY._serialized_options = b'8\001'
  _ROBOT_TAGSENTRY._options = None
  _ROBOT_TAGSENTRY._serialized_options = b'8\001'
  _ROBOTAPPLICATION_TAGSENTRY._options = None
  _ROBOTAPPLICATION_TAGSENTRY._serialized_options = b'8\001'
  _SIMULATIONAPPLICATION_TAGSENTRY._options = None
  _SIMULATIONAPPLICATION_TAGSENTRY._serialized_options = b'8\001'
  _FLEET._serialized_start=76
  _FLEET._serialized_end=257
  _FLEET_TAGSENTRY._serialized_start=214
  _FLEET_TAGSENTRY._serialized_end=257
  _ROBOMAKER._serialized_start=260
  _ROBOMAKER._serialized_end=707
  _ROBOT._serialized_start=710
  _ROBOT._serialized_end=957
  _ROBOT_TAGSENTRY._serialized_start=214
  _ROBOT_TAGSENTRY._serialized_end=257
  _ROBOTAPPLICATIONROBOTSOFTWARESUITE._serialized_start=959
  _ROBOTAPPLICATIONROBOTSOFTWARESUITE._serialized_end=1083
  _ROBOTAPPLICATIONSOURCECONFIG._serialized_start=1086
  _ROBOTAPPLICATIONSOURCECONFIG._serialized_end=1230
  _ROBOTAPPLICATION._serialized_start=1233
  _ROBOTAPPLICATION._serialized_end=1632
  _ROBOTAPPLICATION_TAGSENTRY._serialized_start=214
  _ROBOTAPPLICATION_TAGSENTRY._serialized_end=257
  _ROBOTAPPLICATIONVERSION._serialized_start=1635
  _ROBOTAPPLICATIONVERSION._serialized_end=1767
  _SIMULATIONAPPLICATIONRENDERINGENGINE._serialized_start=1769
  _SIMULATIONAPPLICATIONRENDERINGENGINE._serialized_end=1895
  _SIMULATIONAPPLICATIONSIMULATIONSOFTWARESUITE._serialized_start=1898
  _SIMULATIONAPPLICATIONSIMULATIONSOFTWARESUITE._serialized_end=2032
  _SIMULATIONAPPLICATIONROBOTSOFTWARESUITE._serialized_start=2035
  _SIMULATIONAPPLICATIONROBOTSOFTWARESUITE._serialized_end=2164
  _SIMULATIONAPPLICATIONSOURCECONFIG._serialized_start=2167
  _SIMULATIONAPPLICATIONSOURCECONFIG._serialized_end=2316
  _SIMULATIONAPPLICATION._serialized_start=2319
  _SIMULATIONAPPLICATION._serialized_end=2937
  _SIMULATIONAPPLICATION_TAGSENTRY._serialized_start=214
  _SIMULATIONAPPLICATION_TAGSENTRY._serialized_end=257
  _SIMULATIONAPPLICATIONVERSION._serialized_start=2940
  _SIMULATIONAPPLICATIONVERSION._serialized_end=3077
# @@protoc_insertion_point(module_scope)
